@@ -1,4 +1,5 @@
-from redisconnection import redis_connection, logger
+import redisconnection
+from redisconnection import logger, redis_connection
 
 
 def test_connection():
@@ -8,6 +9,7 @@ def test_connection():
 
 
 if __name__ == '__main__':
+    logger.warning(f'Executing {__file__}')
     test_connection()
 
 
